@@ -1,4 +1,4 @@
-//#define XERR
+#define XERR
 #include "costs.ih"
 
 //code
