@@ -7,7 +7,7 @@
 
 void CT::add(bool *checkRange, LineInfo const &line)
 {
-    Sensitivity sensitivity;
+    Sensitivity sensitivity{ Group{ RANGE } };
 
     if (not Parser::extract(line, sensitivity.group, sensitivity.sens))
     {
@@ -16,7 +16,7 @@ void CT::add(bool *checkRange, LineInfo const &line)
     }
 
     if (                                            // invalid sens. value
-        not (0 <= sensitivity.sens and sensitivity.sens <= 100) 
+        not (0 <= sensitivity.sens and sensitivity.sens <= 100)
         and sensitivity.sens != -1
     )
     {
@@ -26,9 +26,3 @@ void CT::add(bool *checkRange, LineInfo const &line)
 
     d_sensitivity.push_back(move(sensitivity));
 }
-
-
-
-
-
-
