@@ -1,9 +1,11 @@
-#define XERR
+#define XERR "densities"
 #include "densities.ih"
 
 //  #                bi-rad:  a      b      c      d
 //  ageGroup:    0  - 40:    .05    .30    .48    .17
 
+    // by densities1.cc
+
 void Densities::add(bool *checkRange, LineInfo const &line)
 {
     ProbGroup density{ RANGE };
