@@ -3,5 +3,6 @@
 
 Distribution::Distribution(VaryType varyType)
 :
-    d_value(Globals::vary() ? s_varyParam[varyType] : &Distribution::accept)
+    d_value(Globals::vary() ? s_varyParam[varyType] : &Distribution::accept),
+    d_exp(false)
 {}
