@@ -1,9 +1,12 @@
-//#define XERR
+#define XERR "group"
 #include "group.ih"
 
-    //  e.g.,   40 - 50:
-    //          70 - * :
-    // separating blanks are optional
+//  e.g.,   40 - 50:
+//          70 - * :
+// separating blanks are optional, the initial age is optional except for 
+// the first age-range
+
+    // by group.f (operator>>)
 
 std::istream &Group::extract(std::istream &in)
 {
@@ -21,11 +24,21 @@ std::istream &Group::extract(std::istream &in)
         }
     }
     else
-    {
-        in >> d_begin >> sep >> sep;            // get '40 - 5', or '70 - *'
+    {                                           // get '40 - 50', or '70 - *'
+        if (in >> d_begin >> sep >> sep)
+        {
+            if (d_begin < 0)
+                Err::msg(Err::NEGATIVE) << d_begin << endl;
+        }
+        else                                    // no d_begin, then connect
+        {                                       // to the previous range
+            d_begin = -1;
+            in.clear();
+            in >> sep;                          // 1st - read by in >> d_begin
+        }
 
         if (sep == '*')
-            d_end = END_AGE;                    // set end
+            d_end = END_AGE;                    // either set end-age
         else
         {
             in.unget();                         // or extract the age
