@@ -1,12 +1,13 @@
 #define XERR
 #include "loop.ih"
 
-extern size_t g_caseIdx;
+    // by gencases.cc
 
 void Loop::caseInit()
 {
     g_log << "\nLoop::caseInit\n";
 
+    d_modValue = 0;                         // value of the used modality/ies
     d_caseCost = 0;                         // org: womenCosts
     d_roundDetected = -1;                   // org: roundDetected
     d_roundInfo.assign(d_nRounds, '0');     // attendance info per round per
