@@ -1,4 +1,4 @@
-#define XERR
+//#define XERR
 #include "loop.ih"
 
 // with BreastDensities: compute the bi-rad category to use (a: 0 .. d: 3)
@@ -8,8 +8,9 @@ Uint16Vect Loop::cptIndices() const
 {
     Uint16Vect ret;
 
-    if (not Globals::isBreast())
+    if (not Globals::isBreast())    // LC: a 0-initialized vector is used
         ret.resize(d_nRounds);
+
     else                        // for BC: compute the indices used to obtain
     {                           //         dose values
         double prob = Random::instance().uniform();
@@ -27,7 +28,7 @@ Uint16Vect Loop::cptIndices() const
                                 age;
 
                     // store the birad/s3 column index to use for prob/age:
-            ret.push_back(rowCol.first);
+            ret.push_back(rowCol.second);
         }
     }
 
