@@ -1,8 +1,7 @@
 #define XERR
 #include "loop.ih"
 
-size_t g_caseIdx;           // -> loop.ih       if (caseIdx > 24842)
-size_t g_err = 14;
+// size_t g_err = 14;
 
     // by iterate.cc
 
@@ -13,24 +12,19 @@ void Loop::genCases(size_t iter, size_t nCases)
     bool showAll = not d_options.specificAges() and d_options.lastCase() == 0;
 
                                         // perform 'nCases' simulations
-    for (size_t caseIdx = 0; caseIdx != nCases; ++caseIdx)
+    for (size_t d_caseIdx = 0; d_caseIdx != nCases; ++d_caseIdx)
     {
-        g_caseIdx = caseIdx;
-
-        g_log.caseIdx(caseIdx);
+        g_log.caseIdx(d_caseIdx);
         caseInit();             // initialize the data for this case
 
         screening();        // no action unless screening rounds are specified
 
         postScreen();
 
-//FBB        d_sumDeathAge += d_deathAge;
-//FBB        d_totalCost += d_caseCost;
-
-        if (dataTable.stream() and (showAll or caseIdx + 1 == nCases))
+        if (dataTable.stream() and (showAll or d_caseIdx + 1 == nCases))
         {
             d_tumor.checkDeath(d_naturalDeathAge);
-            writeData(dataTable, caseIdx);
+            writeData(dataTable, d_caseIdx);
         }
     }
 
