@@ -58,6 +58,9 @@ class Loop: public Globals
         N_RESULTS = 13              // weird... used in results()
     };
 
+    static StringSet s_availableFiles;
+    static char const *s_status[];
+
     Options const &d_options;
     Status d_status = PRESENT;
 
@@ -71,15 +74,14 @@ class Loop: public Globals
     Modalities d_modalities;
     Screening d_screening;
 
-    int16_t d_roundDetected;        // -1: no detection
+    int16_t d_roundDetected;            // -1: no detection
+    uint16_t d_modValue;                // value of the used modality/ies
 
             // Analysis &d_analysis;
 
             // Beir7 const &d_beir7;
             // Incidence const &d_incidence;
 
-//FBB    double d_sumDeathAge = 0;
-
     double d_naturalDeathAge = 0;      // dying age w/o tumor
     double d_deathAge = 0;             // actual dying age
 
@@ -110,8 +112,6 @@ class Loop: public Globals
     double d_biopCosts;                 // sum of biop costs per case
     DoubleVect d_roundBiopCosts;        // and per round
 
-//FBB    double d_totalCost;
-
     DoubleVect d_roundCost;             // sum of costs over all scr. rounds
                                         // (org: screeningRoundCosts)
 
@@ -129,8 +129,7 @@ class Loop: public Globals
                                             // probGroup::Vector to use when
                                             // constructing d_indices
 
-    static StringSet s_availableFiles;
-    static char const *s_status[];
+    size_t d_caseIdx;               // case idx currently used by genCases
 
     public:
         Loop(StringVect const &labels);
@@ -146,11 +145,12 @@ class Loop: public Globals
         Uint16Vect cptIndices() const;          // cpt d_indices
         static void fillTNM(std::ostream &out);
         static void fillZeroes(std::ostream &out, size_t idx);
-        void genCases(size_t iter, size_t nCases);
+
+        void genCases(size_t iter, size_t nCases);      // generates the
+                                                        // data matrix
 
         FBB::CSVTable headerData(size_t iter) const;
         FBB::CSVTable headerRounds(size_t iter) const;
-//FBB        FBB::CSVTable headerSensitivity() const;
 
         bool intervalCancer();
 
@@ -199,18 +199,6 @@ class Loop: public Globals
         void writeData(FBB::CSVTable &dataTable, size_t idx) const;
         void writeParameters(size_t iter) const;    // also opens the file
         void writeRounds(FBB::CSVTable &roundTable) const;
-//FBB        void writeSensitivity(FBB::CSVTable &sensTable, size_t iter) const;
 };
 
-
-// OBSOLETE
-//        void characteristics(Status natural, Status tumor);
-//        void preTumorDeath();   // early natural death
-//        void preScreen();
-        void preSelfDetected();     // self detected tumor pre-screening
-// covered by 'left(...)'
-//      void setStatus(Status status, double age);  // only sets the d_ vars.
-//        void removeCase(double screeningAge, double selfDetectAge);
-
-
 #endif
