@@ -1,11 +1,11 @@
 #define XERR
 #include "loop.ih"
 
-extern size_t g_caseIdx;
-
     // tumor does exist, but the screening may be negative: false negative
     //                   otherwise: true positive
 
+extern size_t g_caseIdx;
+
         // by screen.cc
 
 void Loop::maybeFalseNegative(ModBase *modBase, double screeningAge)
@@ -19,7 +19,11 @@ void Loop::maybeFalseNegative(ModBase *modBase, double screeningAge)
     {
         tumorDetected(modBase, screeningAge);
         // ++d_nRoundTP[d_round];
+
         modBase->addTruePositive(d_round);
+
+        d_modValue += modBase->value();         // true positive detection
+                                                // by *modBase
     }
 }
 
