@@ -5,9 +5,7 @@ double Loop::sensitivity(ModBase *modBase) const
 {
                 // NOTE: d_indices uses indices (0..4) instead of numbers
                 //       (as used in the original code)
-    double ret = modBase->sensitivity(d_indices[d_round]);
-    //xerr("sens = " << ret);
-    return ret;
+    return modBase->sensitivity(d_indices[d_round]);
 }
 
 ////Calculate sensitivity for the modality and breastdensity (possibility to make function of age and tumorsize in the future but not used for now)
