@@ -1,6 +1,8 @@
 #define XERR
 #include "loop.ih"
 
+    // by gencases.cc
+
 void Loop::writeData(CSVTable &tab, size_t idx) const
 {
     static Status detection[] = { SELF_PRE, SELF_DURING, SELF_POST };
@@ -22,16 +24,14 @@ void Loop::writeData(CSVTable &tab, size_t idx) const
         out << rowCol.first << ',' << rowCol.second;    // row is bc: TNM, col
     }                                                   // = 0 (via Survival::
                                                         // setVSD
-        // self  round
-        // 16    17
-        //       **
     tab << 
-            static_cast<size_t>(round(d_caseCost)) <<                // 15
-            static_cast<size_t>(round(d_biopCosts)) <<            // 15-pre
+            static_cast<size_t>(round(d_caseCost)) <<               // 15
+            static_cast<size_t>(round(d_biopCosts)) <<              // 15-pre
            (find(detection, detection + size(detection), d_status) != 
                           detection + size(detection)) <<           // 16
-           showRound() << d_roundInfo <<                            // 17 - 18
-           out.str();                                               // 19
+
+           to_string(d_modValue) << showRound() << d_roundInfo <<   // 17 - 19
+           out.str();                                               // 20
 }
 
 
