@@ -1,4 +1,4 @@
-#define XERR
+//#define XERR
 #include "mammo.ih"
 
 //code
@@ -19,7 +19,12 @@ double Mammo::vSensitivity(size_t idx) const
             d_beta[3].value() * mValue / (diameter * diameter)
         );
 
-    return  (1 - d_sysErr) * expBeta / (1 + expBeta);
+    double ret = (1 - d_sysErr) * expBeta / (1 + expBeta);
 
+    g_log << __FILE__ " idx = " << idx << ", diameter: " << diameter <<
+            ", m: " << mValue << ", sens.: " << ret << "\n";
+
+    return ret;
 }
 //=
+
