@@ -64,6 +64,11 @@ inline std::string const &ModBase::id() const
     return d_id;
 }
 
+inline uint16_t ModBase::value() const
+{
+    return d_value;
+}
+
 inline double ModBase::dose(uint16_t idx) const
 {
     return vDose(idx);
