@@ -15,7 +15,7 @@ void Options::actualize()                       // transform ~ and +
     replacePlus(d_dataFile[ANALYSIS]);
     replacePlus(d_parametersFile[ANALYSIS]);
     replacePlus(d_roundsFile[ANALYSIS]);
-    replacePlus(d_sensitivityFile[ANALYSIS]);
+//FBB    replacePlus(d_sensitivityFile[ANALYSIS]);
     replacePlus(d_spreadFile[ANALYSIS]);
 
 
