@@ -33,10 +33,10 @@ inline std::string const &Options::roundsFile() const
     return d_roundsFile[ANALYSIS];
 }
 
-inline std::string const &Options::sensitivityFile() const
-{
-    return d_sensitivityFile[ANALYSIS];
-}
+//FBB inline std::string const &Options::sensitivityFile() const
+//FBB {
+//FBB     return d_sensitivityFile[ANALYSIS];
+//FBB }
 
 inline std::string const &Options::spreadFile() const
 {
