@@ -1,4 +1,4 @@
-inline uint16_t ProbGroup::begin() const
+inline double ProbGroup::begin() const
 {
     return d_group.begin();
 }
@@ -8,7 +8,7 @@ inline bool ProbGroup::contains(double value) const
     return d_group.contains(value);
 }
 
-inline uint16_t ProbGroup::end() const
+inline double ProbGroup::end() const
 {
     return d_group.end();
 }
