@@ -36,7 +36,10 @@ bool Screening::addModality(istream &in, Round &round)
             // TODO: the last entry in d_roundVect (may still be empty)
             //       may not contain modality 'idx'
             if (round.add(idx))
+            {
+                d_modalities.activate(modality);
                 continue;
+            }
 
             context = Err::MODALITY_REPEATED;
         }
