@@ -1,3 +1,8 @@
+inline bool Screening::attend(size_t idx) const         // 24/1
+{
+    return d_attend[idx];
+}
+
 inline double Screening::rate() const
 {
     return d_rate;
