@@ -1,6 +1,8 @@
-#define XERR
+#define XERR "simuator"
 #include "simulator.ih"
 
+    // by ./main.cc
+
 //code
 void Simulator::run()
 {
