@@ -21,7 +21,7 @@ void Tumor::reset()
         d_doublingYears = NO_TUMOR;
 //        d_selfDetect = 0;
         d_prePeriod = NO_TUMOR;
-        d_detectableAge = NO_TUMOR;
+        d_onset = NO_TUMOR;
         return;
     }
 
@@ -39,8 +39,16 @@ void Tumor::reset()
 
     d_doublingYears = d_doublingDays / N_YEARDAYS;
 
-    double selfDetectDiam = random.logNormal(d_growth.selfMu().value(),
+    double selfDetectDiam;
+
+    while (true)
+    {
+        selfDetectDiam = random.logNormal(d_growth.selfMu().value(),
                                              d_growth.selfSigma());
+        g_log << "try selfDetectDiam = " << selfDetectDiam << '\n';
+        if (selfDetectDiam > d_growth.start())
+            break;
+    }
 
     d_prePeriod =   d_doublingDays *
                     log(
@@ -48,13 +56,20 @@ void Tumor::reset()
                         volume(d_growth.start())
                     ) * s_log2YearInv;
 
-    d_detectableAge = d_selfDetectAge - d_prePeriod;
+    d_onset = d_selfDetectAge - d_prePeriod;
 
     g_log << "\nTUMOR RESET:\n"
-             "  selfDetectDiam = " << selfDetectDiam << "\n"
              "  selfDetectAge =  " << d_selfDetectAge << "\n"
-             "  growth start =   " << d_growth.start() << "\n"
-             "  p(survival) =    " << d_pSurvival << "\n"
              "  preperiod =      " << d_prePeriod << "\n"
-             "  detectableAge = " << d_detectableAge << '\n';
+             "  onset =          " << d_onset << "\n"
+             "  doubingDays =    " << d_doublingDays << "\n"
+             "  selfDetectDiam = " << selfDetectDiam << "\n"
+             "  volume(..) =     " << volume(selfDetectDiam) << "\n"
+             "  growth start =   " << d_growth.start() << "\n"
+             "  volume(..) =     " << volume(d_growth.start()) << "\n"
+             "  p(survival) =    " << d_pSurvival << '\n';
 }
+
+
+
+
