@@ -8,11 +8,21 @@ inline double Tumor::onset() const
     return d_onset;
 }
 
-inline bool Tumor::selfDetectable() const
+inline bool Tumor::at(double age) const
 {
-    return d_selfDetectAge != NO_TUMOR;
+    return d_onset <= age;
 }
 
+inline bool Tumor::selfDetectBefore(double age) const
+{
+    return d_selfDetectAge <= age;
+}
+
+// inline bool Tumor::selfDetectable() const
+// {
+//     return d_selfDetectAge != NO_TUMOR;
+// }
+// 
 // inline void Tumor::characteristics()
 // {
 //     characteristics(d_selfDetectAge);
