@@ -24,7 +24,7 @@ class TumorInfo: public Globals
     public:
         void vary(std::ostream &out);           // vary parameters
 
-        Incidence const &incidence() const;
+//        Incidence const &incidence() const;
 
         uint16_t  induction() const;            // beir model to use
         Beir7     const &beir7() const;
@@ -41,10 +41,10 @@ class TumorInfo: public Globals
         void totalRiskFile() const;
 };
 
-inline Incidence const &TumorInfo::incidence() const
-{
-    return d_incidence;
-}
+//inline Incidence const &TumorInfo::incidence() const
+//{
+//    return d_incidence;
+//}
 
 inline Beir7 const &TumorInfo::beir7() const
 {
