@@ -4,6 +4,6 @@
 VSD::VSD(VaryType varyType)
 :
     d_dist(varyType),
-    d_valueCheck(s_valueCheck[varyType])
-{
-}
+    d_valueCheck(s_valueCheck[varyType]),
+    d_exp(false)
+{}
